@@ -7,7 +7,7 @@ import sys
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 
-__version__ = '0.2.1'
+__version__ = '0.2.2'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
@@ -248,18 +248,26 @@ class HelpParser(object):
                     help_string = line[helpstring_offset:]
                 else:
                     help_string = ""
-                tmp = line.split(', ')
-                if tmp[1][:2] == '--':
-                    longopt = tmp[1]
-                    if '=' in longopt:
-                        longtmp = longopt.split("=")
-                        longopt = longtmp[0]
-                        metavar = longtmp[1]
-                    else:
-                        longopt = tmp[1].split()[0]
-                else:   # found metavar
-                    metavar = tmp[1][:-1]
-                    longopt = tmp[2].split("=")[0]
+                # check exist longopt
+                if line.find(', --') != -1:     # exist long option
+                    tmp = line.split(', ')
+                    if tmp[1][:2] == '--':
+                        longopt = tmp[1]
+                        if '=' in longopt:
+                            longtmp = longopt.split("=")
+                            longopt = longtmp[0]
+                            metavar = longtmp[1]
+                        else:
+                            longopt = tmp[1].split()[0]
+                    else:   # found metavar
+                        metavar = tmp[1][:-1]
+                        longopt = tmp[2].split("=")[0]
+                else:                           # not exist long option
+                    tmp = line.split()
+                    shortopt = tmp[0]
+                    metavar = tmp[1]
+                    if len(tmp) > 2:
+                        help_string += line[helpstring_offset - 1]
                 option_list.append({'short': shortopt,
                                     'long': longopt,
                                     'metavar': metavar,
@@ -288,15 +296,15 @@ def main():
         return -1
     else:
         helptext = ""
+        poller = poll()
+        poller.register(sys.stdin, POLLIN)
         while True:
-            poller = poll()
-            poller.register(sys.stdin, POLLIN)
             ret = poller.poll()
-            if len(ret) == 1 and ret[0][1] & POLLIN:
-                helptext += sys.stdin.read()
-            elif len(ret) == 1 and ret[0][1] & POLLHUP:
+            if len(ret) == 1 and ret[0][1] & POLLHUP:
                 helptext += sys.stdin.read()
                 break
+            elif len(ret) == 1 and ret[0][1] & POLLIN:
+                helptext += sys.stdin.read()
     help_parser = HelpParser(helptext)
     command_name = help_parser.get_commandname()
     option_parser = help_parser.help2optparse()
